@@ -23,15 +23,11 @@ from __future__ import print_function
 
 import imp
 import os
-import sys
 import zipimport
 
-import six
-
 from astroid import exceptions
 from astroid import modutils
 from astroid import transforms
-from astroid import util
 
 
 def safe_repr(obj):
@@ -83,7 +79,7 @@ class AstroidManager(object):
                 modname = '.'.join(modutils.modpath_from_file(filepath))
             except ImportError:
                 modname = filepath
-        if modname in self.astroid_cache and self.astroid_cache[modname].file == filepath:
+        if modname in self.astroid_cache and self.astroid_cache[modname].source_file == filepath:
             return self.astroid_cache[modname]
         if source:
             from astroid.builder import AstroidBuilder
@@ -127,9 +123,9 @@ class AstroidManager(object):
                     return self._build_stub_module(modname)
                 try:
                     module = modutils.load_module_from_name(modname)
-                except Exception as ex: # pylint: disable=broad-except
+                except Exception as ex:
                     msg = 'Unable to load module %s (%s)' % (modname, ex)
-                    util.reraise(exceptions.AstroidBuildingException(msg))
+                    raise exceptions.AstroidBuildingException(msg)
                 return self.ast_from_module(module, modname)
             elif mp_type == imp.PY_COMPILED:
                 msg = "Unable to load compiled module %s" % (modname,)
@@ -171,22 +167,19 @@ class AstroidManager(object):
         return None
 
     def file_from_module_name(self, modname, contextfile):
+        # pylint: disable=redefined-variable-type
         try:
             value = self._mod_file_cache[(modname, contextfile)]
-            traceback = sys.exc_info()[2]
         except KeyError:
             try:
                 value = modutils.file_info_from_modpath(
                     modname.split('.'), context_file=contextfile)
-                traceback = sys.exc_info()[2]
             except ImportError as ex:
                 msg = 'Unable to load module %s (%s)' % (modname, ex)
                 value = exceptions.AstroidBuildingException(msg)
-                traceback = sys.exc_info()[2]
             self._mod_file_cache[(modname, contextfile)] = value
         if isinstance(value, exceptions.AstroidBuildingException):
-            six.reraise(exceptions.AstroidBuildingException,
-                        value, traceback)
+            raise value
         return value
 
     def ast_from_module(self, module, modname=None):
@@ -211,7 +204,7 @@ class AstroidManager(object):
                 modname = klass.__module__
             except AttributeError:
                 msg = 'Unable to get module for class %s' % safe_repr(klass)
-                util.reraise(exceptions.AstroidBuildingException(msg))
+                raise exceptions.AstroidBuildingException(msg)
         modastroid = self.ast_from_module_name(modname)
         return modastroid.getattr(klass.__name__)[0] # XXX
 
@@ -225,20 +218,20 @@ class AstroidManager(object):
             modname = klass.__module__
         except AttributeError:
             msg = 'Unable to get module for %s' % safe_repr(klass)
-            util.reraise(exceptions.AstroidBuildingException(msg))
-        except Exception as ex: # pylint: disable=broad-except
+            raise exceptions.AstroidBuildingException(msg)
+        except Exception as ex:
             msg = ('Unexpected error while retrieving module for %s: %s'
                    % (safe_repr(klass), ex))
-            util.reraise(exceptions.AstroidBuildingException(msg))
+            raise exceptions.AstroidBuildingException(msg)
         try:
             name = klass.__name__
         except AttributeError:
             msg = 'Unable to get name for %s' % safe_repr(klass)
-            util.reraise(exceptions.AstroidBuildingException(msg))
-        except Exception as ex: # pylint: disable=broad-except
+            raise exceptions.AstroidBuildingException(msg)
+        except Exception as ex:
             exc = ('Unexpected error while retrieving name for %s: %s'
                    % (safe_repr(klass), ex))
-            util.reraise(exceptions.AstroidBuildingException(exc))
+            raise exceptions.AstroidBuildingException(exc)
         # take care, on living object __module__ is regularly wrong :(
         modastroid = self.ast_from_module_name(modname)
         if klass is obj:
@@ -246,7 +239,7 @@ class AstroidManager(object):
                 yield inferred
         else:
             for inferred in modastroid.igetattr(name, context):
-                yield inferred.instanciate_class()
+                yield inferred.instantiate_class()
 
     def register_failed_import_hook(self, hook):
         """Registers a hook to resolve imports that cannot be found otherwise.
