@@ -53,14 +53,15 @@ class AsStringTest(resources.SysPathSetup, unittest.TestCase):
         self.assertEqual(build('(1, )').as_string(), '(1, )')
         self.assertEqual(build('1, 2, 3').as_string(), '(1, 2, 3)')
 
-    @test_utils.require_version(minver='3.0')
-    def test_func_signature_issue_185(self):
-        code = textwrap.dedent('''
-        def test(a, b, c=42, *, x=42, **kwargs):
-            print(a, b, c, args)
+    def test_as_string_for_list_containing_uninferable(self):
+        node = test_utils.extract_node('''
+        def foo(arg):
+            bar = [arg] * 1
         ''')
-        node = parse(code)
-        self.assertEqual(node.as_string().strip(), code.strip())
+        binop = node.body[0].value
+        inferred = next(binop.infer())
+        self.assertEqual(inferred.as_string(), '[Uninferable]')
+        self.assertEqual(binop.as_string(), '([arg]) * (1)')
 
     def test_frozenset_as_string(self):
         nodes = test_utils.extract_node('''
@@ -80,6 +81,14 @@ class AsStringTest(resources.SysPathSetup, unittest.TestCase):
         self.assertNotEqual(nodes[3].as_string(), 'frozenset(None)')
         self.assertNotEqual(nodes[4].as_string(), 'frozenset(1)')
 
+    @test_utils.require_version(minver='3.0')
+    def test_func_signature_issue_185(self):
+        code = textwrap.dedent('''
+        def test(a, b, c=42, *, x=42, **kwargs):
+            print(a, b, c, args)
+        ''')
+        node = parse(code)
+        self.assertEqual(node.as_string().strip(), code.strip())
     def test_varargs_kwargs_as_string(self):
         ast = abuilder.string_build('raise_string(*args, **kwargs)').body[0]
         self.assertEqual(ast.as_string(), 'raise_string(*args, **kwargs)')
@@ -393,11 +402,11 @@ from ..cave import wine\n\n"""
         next(astroid['message'].infer(ctx))
         ctx.lookupname = 'email'
         m = next(astroid['email'].infer(ctx))
-        self.assertFalse(m.file.startswith(os.path.join('data', 'email.py')))
+        self.assertFalse(m.source_file.startswith(os.path.join('data', 'email.py')))
 
     def test_more_absolute_import(self):
         astroid = resources.build_file('data/module1abs/__init__.py', 'data.module1abs')
-        self.assertIn('sys', astroid.locals)
+        self.assertIn('sys', astroid._locals)
 
 
 class CmpNodeTest(unittest.TestCase):
@@ -525,6 +534,7 @@ class BoundMethodNodeTest(unittest.TestCase):
             pass
         def lazyproperty():
             pass
+        def lazy(): pass
         class A(object):
             @property
             def builtin_property(self):
@@ -541,6 +551,8 @@ class BoundMethodNodeTest(unittest.TestCase):
             @lazyproperty
             def lazyprop(self): return 42
             def not_prop(self): pass
+            @lazy
+            def decorated_with_lazy(self): return 42
 
         cls = A()
         builtin_property = cls.builtin_property
@@ -550,9 +562,10 @@ class BoundMethodNodeTest(unittest.TestCase):
         not_prop = cls.not_prop
         lazy_prop = cls.lazy_prop
         lazyprop = cls.lazyprop
+        decorated_with_lazy = cls.decorated_with_lazy
         ''')
         for prop in ('builtin_property', 'abc_property', 'cached_p', 'reified',
-                     'lazy_prop', 'lazyprop'):
+                     'lazy_prop', 'lazyprop', 'decorated_with_lazy'):
             inferred = next(ast[prop].infer())
             self.assertIsInstance(inferred, nodes.Const, prop)
             self.assertEqual(inferred.value, 42, prop)
@@ -590,8 +603,9 @@ class AliasesTest(unittest.TestCase):
 
         def test_assname(node):
             if node.name == 'foo':
-                return nodes.AssignName('bar', node.lineno, node.col_offset,
-                                        node.parent)
+                n = nodes.AssignName()
+                n.name = 'bar'
+                return n
         def test_assattr(node):
             if node.attrname == 'a':
                 node.attrname = 'b'
@@ -604,8 +618,7 @@ class AliasesTest(unittest.TestCase):
 
         def test_genexpr(node):
             if node.elt.value == 1:
-                node.elt = nodes.Const(2, node.lineno, node.col_offset,
-                                       node.parent)
+                node.elt = nodes.Const(2)
                 return node
 
         self.transformer.register_transform(nodes.From, test_from)
